Learn R Programming

nortestARMA (version 1.0.2)

Piggott:

Description

Two series consisting of daily temperature values and the (square root transformed) wind speed series obtained from Piggott (1980). This data set was first studied by Shea (1987) and then by Ducharme et al. (2004).

Usage

data(Piggott)

Arguments

Format

A data frame with 366 observations on the following 2 variables.
temp
numeric vector of daily temperatures.
wind.trans
numeric vector of the (square root transformed) wind speed series.

References

Ducharme G., Lafaye de Micheaux P., (2004). Goodness-of-fit tests of normality for the innovations in ARMA models. Journal of Time Series Analysis 25 (3), 373--395. Duchesne P., Lafaye de Micheaux P., Tagne J. (2016). Neyman Smooth Test of Normality for ARMA Time Series Models with Unknown Mean. Submitted. Piggott J. L., (1980). The use o f Box-Jenkins modelling for the forecasting of daily gas demand. Paper presented to the Royal Statistical Society. Shea B. L., (1987). Estimation of Multivariate Time Series. Journal of Time Series Analysis 8 (1), 95--109.

Examples

Run this code
data(Piggott)

Run the code above in your browser using DataLab