Learn R Programming

nortestARMA (version 1.0.2)

potato:

Description

We retrieved the data from the Canadian Socio-Economic Information Management System (CANSIM), which is a computerized database of Statistics Canada. The time series consists of annual data on the productivity of potatoes (per acre) in Prince Edward Island for the time period 1957-2014 (CANSIM Series V47152).

Usage

data(potato)

Arguments

Format

A data frame with 58 observations on the following 2 variables.
year
numeric vector of the years of harvest
potatoeyield
numeric vector of the productivity of potatoes (Hundredweight per harvested acres)

References

Cheng H., (2005). Competitive relationship among potato production areas in northeastern america. Journal of Food Distribution Research Proceedings 36 (1), 27--32. Ducharme G., Lafaye de Micheaux P., (2004). Goodness-of-fit tests of normality for the innovations in ARMA models. Journal of Time Series Analysis 25 (3), 373--395. Duchesne P., Lafaye de Micheaux P., Tagne J. (2016). Neyman Smooth Test of Normality for ARMA Time Series Models with Unknown Mean. Submitted.

Examples

Run this code
data(potato)

Run the code above in your browser using DataLab